@@ -1,4 +1,4 @@
-#!/usr/bin/env python2
+#!/usr/bin/python2
 
 from GSettingsWidgets import *
 from gi.repository import *
@@ -26,6 +26,7 @@ DEF_HEADING = 2
 preferred_app_defs = [
     # 1st mimetype is to let us find apps
     # 2nd mimetype is to set default handler for (so we handle all of that type, not just a specific format)
+    ( "inode/directory",         "inode/directory",            _("File Manager") ),
     ( "x-scheme-handler/http",   "x-scheme-handler/http",      _("_Web") ),
     ( "x-scheme-handler/mailto", "x-scheme-handler/mailto",    _("_Mail") ),
     ( "application/msword",      "application/msword",       _("Documents") ),
@@ -192,6 +193,8 @@ class MnemonicLabel(Gtk.Label):
         super(MnemonicLabel, self).__init__(label = "")
         self.set_text_with_mnemonic(text)
         self.set_mnemonic_widget(widget)
+        self.set_alignment(0.0, 0.5)
+        self.set_line_wrap(True)
 
 class DefaultAppChooserButton(Gtk.AppChooserButton):
     def __init__(self, content_type, gen_content_type):
@@ -276,6 +279,8 @@ class CustomAppChooserButton(Gtk.AppChooserButton):
         self.media_settings = media_settings
         content_type = self.get_content_type()
 
+        self.set_valign(Gtk.Align.CENTER)
+
         #fetch preferences for this content type
         (pref_start_app, pref_ignore, pref_open_folder) = self.getPreferences()
         pref_ask = not pref_start_app and not pref_ignore and not pref_open_folder
